==> 1.0.9.tar.gz: lib/tiledjsonreader.dart <==
library tiledjsonreader;

import 'dart:async' as syc;
import 'dart:convert';
import 'dart:io' as io;
import 'package:path_provider/path_provider.dart' as ppo;

import 'map/tile_set_detail.dart';
import 'map/tiled_map.dart';
import 'tile_set/tile_set.dart';

class TiledJsonReader {
  final String pathFile;
  String? _basePathFile;
  String? _fileName;
  TiledMap? _map;

  TiledJsonReader(this.pathFile) {
    _fileName = pathFile.split('/').last;
    if (_fileName?.contains('.json') != true) {
      throw Exception('only supports json files');
    }
    _basePathFile = pathFile.replaceAll(_fileName ?? '', '');
  }

  //troquei a origin do repositorio github para gitlab

  syc.Future<String> get _localPath async {
    final directory = await ppo.getApplicationDocumentsDirectory();

    return directory.path;
  }

  syc.Future<String> _localFile(lc) async {
    final path = await _localPath;
    return io.File('$path/$lc').readAsString();
  }

  Future<TiledMap> read() async {
    //String data = await rootBundle.loadString(pathFile);
    String data = await _localFile(pathFile);
    Map<String, dynamic> _result = jsonDecode(data);
    _map = TiledMap.fromJson(_result);
    if (_map?.tileSets != null) {
      await Future.forEach(_map!.tileSets!, (TileSetDetail tileSet) async {
        if (!tileSet.source!.contains('.json')) {
          throw Exception('Invalid TileSet source: only supports json files');
        }
        /* String data = await rootBundle.loadString(
          '$_basePathFile${tileSet.source}',
        ); */
        String data = await _localFile('$_basePathFile${tileSet.source}');
        Map<String, dynamic> _result = jsonDecode(data);
        tileSet.tileSet = TileSet.fromJson(_result);
      });
    }

    return Future.value(_map);
  }
}

==> 1.0.11.tar.gz: lib/tiledjsonreader.dart <==
library tiledjsonreader;

import 'dart:async' as syc;
import 'dart:convert';
import 'dart:io' as io;
import 'package:flutter/services.dart';
import 'package:path_provider/path_provider.dart' as ppo;

import 'map/tile_set_detail.dart';
import 'map/tiled_map.dart';
import 'tile_set/tile_set.dart';

class TiledJsonReader {
  final String pathFile;
  String? _basePathFile;
  String? _fileName;
  TiledMap? _map;

  TiledJsonReader(this.pathFile) {
    _fileName = pathFile.split('/').last;
    if (_fileName?.contains('.json') != true) {
      throw Exception('only supports json files');
    }
    _basePathFile = pathFile.replaceAll(_fileName ?? '', '');
  }

  //troquei a origin do repositorio github para gitlab

  syc.Future<String?> get _localPath async {
    io.Directory? directory;
    try {
      if (io.Platform.isIOS) {
        directory = await ppo.getApplicationDocumentsDirectory();
      } else {
        directory = io.Directory('/storage/emulated/0/Download');
        // Put file in global download folder, if for an unknown reason it didn't exist, we fallback
        // ignore: avoid_slow_async_io
        if (!await directory.exists()){
          directory = await ppo.getExternalStorageDirectory();
          directory = io.Directory('/storage/emulated/0/Download');
        }
      }
    } catch (err, stack) {
      print("Cannot get download folder path");
    }
    return directory?.path;
    /* final directory = await ppo.getApplicationDocumentsDirectory();

    return directory.path; */
  }

  syc.Future<String> _localFile(lc) async {
    final path = await _localPath;
    return io.File('$path/$lc').readAsString();
  }

  Future<TiledMap> read() async {
    //String data = await rootBundle.loadString(pathFile);
    String data = await _localFile(pathFile);
    Map<String, dynamic> _result = jsonDecode(data);
    _map = TiledMap.fromJson(_result);
    if (_map?.tileSets != null) {
      await Future.forEach(_map!.tileSets!, (TileSetDetail tileSet) async {
        if (!tileSet.source!.contains('.json')) {
          throw Exception('Invalid TileSet source: only supports json files');
        }
        /* String data = await rootBundle.loadString(
          '$_basePathFile${tileSet.source}',
        ); */
        String data = await _localFile('$_basePathFile${tileSet.source}');
        Map<String, dynamic> _result = jsonDecode(data);
        tileSet.tileSet = TileSet.fromJson(_result);
      });
    }

    return Future.value(_map);
  }
}
